=============
Bilby example
=============

``nessai`` can be used like any of the other samplers in ``bilby`` and the full range of settings are available.
The following example mirrors the :doc:`Gaussian example<gaussian-example>` but using ``bilby``.

.. note::

    As of ``bilby`` v2.3.0, the recommended way to use ``nessai`` is via the ``nessai-bilby`` plugin, see :ref:`nessai-bilby`.

Code
====

.. literalinclude:: ../examples/bilby_example.py
    :language: python
